aboutsummaryrefslogtreecommitdiffstats
path: root/ethstats
diff options
context:
space:
mode:
authorrjl493456442 <garyrong0905@gmail.com>2018-05-10 15:04:45 +0800
committerPéter Szilágyi <peterke@gmail.com>2018-05-18 16:46:44 +0800
commita2e43d28d01ef9642c7f6992b78b86bd0696c847 (patch)
tree2f5d3444071125e84155321db6fd79d941cfee0b /ethstats
parent6286c255f16a914b39ffd3389cba154a53e66a13 (diff)
downloaddexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar.gz
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar.bz2
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar.lz
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar.xz
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.tar.zst
dexon-a2e43d28d01ef9642c7f6992b78b86bd0696c847.zip
all: collate new transaction events together
Diffstat (limited to 'ethstats')
-rw-r--r--ethstats/ethstats.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/ethstats/ethstats.go b/ethstats/ethstats.go
index a15d84615..17f9f3c7a 100644
--- a/ethstats/ethstats.go
+++ b/ethstats/ethstats.go
@@ -49,7 +49,7 @@ const (
// history request.
historyUpdateRange = 50
// txChanSize is the size of channel listening to TxPreEvent.
// The number is referenced from the size of tx pool.
txChanSize = 4096
// chainHeadChanSize is the size of channel listening to ChainHeadEvent.
@@ -58,8 +58,8 @@ const (
type txPool interface {
// SubscribeTxPreEvent should return an event subscription of
- // TxPreEvent and send events to the given channel.
- SubscribeTxPreEvent(chan<- core.TxPreEvent) event.Subscription
+ // TxsPreEvent and send events to the given channel.
+ SubscribeTxPreEvent(chan<- core.TxsPreEvent) event.Subscription
}
type blockChain interface {
@@ -150,7 +150,7 @@ func (s *Service) loop() {
headSub := blockchain.SubscribeChainHeadEvent(chainHeadCh)
defer headSub.Unsubscribe()
- txEventCh := make(chan core.TxPreEvent, txChanSize)
+ txEventCh := make(chan core.TxsPreEvent, txChanSize)
txSub := txpool.SubscribeTxPreEvent(txEventCh)
defer txSub.Unsubscribe()
@@ -49,7 +49,7 @@ const (
// history request.
historyUpdateRange = 50
- // txChanSize is the size of channel listening to TxPreEvent.
+ // txChanSize is the size of channel listening to TxsPreEvent.
// The number is referenced from the size of tx pool.
txChanSize = 4096